#!/bin/bash

# helper tool to archvie up results
# call as archive_results.sh
# it produces output files in the current directory and expects to be called
# from somewhere wehre simfactory is accessible (either in $PWD or in
# $CACTUS_PATH)

set -x
set -e

DIRNAME=bns-$(date +%Y%m%d)

mkdir $DIRNAME $DIRNAME/bns
cp bns.out mp_Psi4_l2_m2_r300.00.asc bns.par rho.xy.h5 $DIRNAME/bns/

# generate some README file
RANKS=$(gawk '/NFO [(]Carpet[)]: Carpet is running on [0-9]* processes/{print $7}' bns.out)
WALLTIME_USED=$(gawk '
BEGIN {
  LENGTH = 0.;
  TIME = 0.;
}
/^[0-9]/ {
  if($5+0. < TIME) { # evolution time wend down -> new segment
    LENGTH += TIME;
  }
  TIME = $5 + 0.;
}
END {
  LENGTH += TIME;
  print LENGTH/3600.;
}
' carpet-timing..asc)
WHOAMI=$(${CACTUS_PATH+$CACTUS_PATH/}./simfactory/bin/sim whoami | gawk '/Current machine:/{print $3}')

cat >$DIRNAME/README.md <<EOF
The data produced on $(date +%Y-%m-%d) was produced using $RANKS MPI ranks on
the $WHOAMI system. 
It took a walltime of $WALLTIME_USED hrs to finish.
EOF

tar -czf $DIRNAME.tar.gz $DIRNAME
